# Question

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**columns** | [**list[GridColumn]**](GridColumn.md) |  | [optional] 
**default_rows** | **list[dict(str, object)]** |  | [optional] 
**field_associated** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**label** | **str** |  | [optional] 
**label_arg** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**options** | **list[str]** |  | [optional] 
**placeholder** | **str** |  | [optional] 
**required** | **bool** |  | [optional] 
**tooltip** | **str** |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


